@@ -75,9 +75,13 @@ class Provider(BaseProvider):
         return string
 
     @lowercase
-    def email(self):
-        pattern = self.random_element(self.email_formats)
-        return "".join(self.generator.parse(pattern).split(" "))
+    def email(self, domain=None):
+        if domain:
+            email = '{0}@{1}'.format(self.user_name(), domain)
+        else:
+            pattern = self.random_element(self.email_formats)
+            email = "".join(self.generator.parse(pattern).split(" "))
+        return email
 
     @lowercase
     def safe_email(self):
